aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2019-01-31 11:59:03 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2019-01-31 11:59:03 +0200
commit66d3bf73c4853c081214620eb53a32ea89b473b1 (patch)
treed540b0e88babd1a2c83b59373ffd60070446eaa8
parent5b58e64b60410d3b763915faad484d569da26dea (diff)
Increase build mis-boot timeout from 60 to 90 seconds
-rw-r--r--bbot/agent/agent.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/bbot/agent/agent.cxx b/bbot/agent/agent.cxx
index 67d503d..5fecd0e 100644
--- a/bbot/agent/agent.cxx
+++ b/bbot/agent/agent.cxx
@@ -866,12 +866,12 @@ try
};
// The first request should be the task manifest download. Wait for up
// to 60 seconds for that to arrive. In a sense we use it as an
// indication that the machine has booted and the worker process has
// started.
//
size_t to;
- const size_t startup_to (60);
+ const size_t startup_to (90);
const size_t build_to (ops.build_timeout ());
if (!tftpd.serve ((to = startup_to)))
@@ -866,12 +866,12 @@ try
};
// The first request should be the task manifest download. Wait for up
- // to 60 seconds for that to arrive. In a sense we use it as an
+ // to 90 seconds for that to arrive. In a sense we use it as an
// indication that the machine has booted and the worker process has
// started.